Position

Struct Position 

pub struct Position<Rep, T> { /* private fields */ }
๐Ÿ‘ŽDeprecated since 0.2.0
Position.

Implementations

Source

impl<Rep: Representation, T: PositionNum> Position<Rep, T>

pub fn new(price: T, size: T, value: T) -> Option<Self>

๐Ÿ‘ŽDeprecated since 0.2.0

Create a new Position.

pub fn from_naive<H: IntoNaivePosition<T>>(naive: H) -> Option<Self>

๐Ÿ‘ŽDeprecated since 0.2.0

Create a new Position from IntoNaivePosition.

This method will convert the price and size of naive by Rep.

pub fn consumed(&self) -> Option<Self>

๐Ÿ‘ŽDeprecated since 0.2.0

Return a new position that consumes its value. (Equivalence I).

Return None if size is zero.

pub fn consume(&mut self)

๐Ÿ‘ŽDeprecated since 0.2.0

Consume value.

No effect if size is zero.

pub fn converted(&self, price: T) -> Self

๐Ÿ‘ŽDeprecated since 0.2.0

Return a new position with the given price but keep equivalent to the original position. (Equivalence II)

pub fn convert(&mut self, price: T)

๐Ÿ‘ŽDeprecated since 0.2.0

Convert the price to the given but keep equivalent to the original. (Equivalence II)

pub fn price(&self) -> Option<T>

๐Ÿ‘ŽDeprecated since 0.2.0

Price in Rep representation.

Return None if naive price is zero when Rep is reversed.

pub fn size(&self) -> T

๐Ÿ‘ŽDeprecated since 0.2.0

Size in Rep representation.

pub fn value(&self) -> &T

๐Ÿ‘ŽDeprecated since 0.2.0

Value.

pub fn naive_price(&self) -> &T

๐Ÿ‘ŽDeprecated since 0.2.0

Naive price.

pub fn naive_size(&self) -> &T

๐Ÿ‘ŽDeprecated since 0.2.0

Naive size.

pub fn take(&mut self) -> T

๐Ÿ‘ŽDeprecated since 0.2.0

Take the value and keep the price and size unchanged.

After the operation, the new position is no longer equivalent to the original.