pub struct Position<Rep, T> { /* private fields */ }๐Deprecated since 0.2.0
Position.
Implementations
Sourceimpl<Rep: Representation, T: PositionNum> Position<Rep, T>
impl<Rep: Representation, T: PositionNum> Position<Rep, T>
Sourcepub fn new(price: T, size: T, value: T) -> Option<Self>
๐Deprecated since 0.2.0
pub fn new(price: T, size: T, value: T) -> Option<Self>
Create a new Position.
Sourcepub fn from_naive<H: IntoNaivePosition<T>>(naive: H) -> Option<Self>
๐Deprecated since 0.2.0
pub fn from_naive<H: IntoNaivePosition<T>>(naive: H) -> Option<Self>
Create a new Position from IntoNaivePosition.
This method will convert the price and size of naive by Rep.
Sourcepub fn consumed(&self) -> Option<Self>
๐Deprecated since 0.2.0
pub fn consumed(&self) -> Option<Self>
Return a new position that consumes its value. (Equivalence I).
Return None if size is zero.
Sourcepub fn converted(&self, price: T) -> Self
๐Deprecated since 0.2.0
pub fn converted(&self, price: T) -> Self
Return a new position with the given price
but keep equivalent to the original position.
(Equivalence II)
Sourcepub fn convert(&mut self, price: T)
๐Deprecated since 0.2.0
pub fn convert(&mut self, price: T)
Convert the price to the given but keep equivalent to the original. (Equivalence II)
Sourcepub fn price(&self) -> Option<T>
๐Deprecated since 0.2.0
pub fn price(&self) -> Option<T>
Price in Rep representation.
Return None if naive price is zero when Rep is reversed.
Sourcepub fn naive_price(&self) -> &T
๐Deprecated since 0.2.0
pub fn naive_price(&self) -> &T
Naive price.
Sourcepub fn naive_size(&self) -> &T
๐Deprecated since 0.2.0
pub fn naive_size(&self) -> &T
Naive size.